<?php
namespace Plumbio\Helper\Elementor\Widgets;

use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Widget_Base;
use Elementor\Plugin;
use Elementor\Repeater;

class Special_Offers extends Widget_Base {


	public function get_name() {
		return 'special_offers';
	}

	public function get_title() {
		return esc_html__( 'Special Offers', 'plumbio-core' );
	}

	public function get_icon() {
		return 'sds-widget-ico';
	}

	public function get_categories() {
		return array( 'plumbio' );
	}

	protected function register_controls() {
		$this->start_controls_section(
			'general',
			array(
				'label' => esc_html__( 'general', 'plumbio-core' ),
			)
		);

		$this->add_control(
			'block_title',
			array(
				'label'   => esc_html__( 'Block BG', 'plumbio-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'Special', 'plumbio-core' ),
			)
		);

		$this->add_control(
			'tag_line',
			array(
				'label'   => esc_html__( 'Tag Line', 'plumbio-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'what we offer', 'plumbio-core' ),
			)
		);

		$this->add_control(
			'heading',
			array(
				'label'   => esc_html__( 'Heading', 'plumbio-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( "What's Included?", 'plumbio-core' ),
			)
		);

		$this->add_control(
			'description',
			array(
				'label'       => esc_html__( 'Description', 'plumbio-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 6,
				'default'     => __( '', 'plumbio-core' ),
				'placeholder' => esc_html__( 'Type your description here', 'plumbio-core' ),

			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'item',
			array(
				'label' => esc_html__( 'item', 'plumbio-core' ),
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'item_coupon_price',
			array(
				'label'   => esc_html__( 'Coupon  Price', 'plumbio-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( '-$50', 'plumbio-core' ),
			)
		);

		$repeater->add_control(
			'item_coupon_price_text',
			array(
				'label'   => esc_html__( 'Coupon Price Text', 'plumbio-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'offer', 'plumbio-core' ),
			)
		);

		$repeater->add_control(
			'item_coupon_subtitle',
			array(
				'label'   => esc_html__( 'Coupon Subtitle', 'plumbio-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'SPECIAL OFFER', 'plumbio-core' ),
			)
		);

		$repeater->add_control(
			'item_coupon_title',
			array(
				'label'   => esc_html__( 'Coupon Title', 'plumbio-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'Drain Testing', 'plumbio-core' ),
			)
		);

		$repeater->add_control(
			'item_coupon_content',
			array(
				'label'   => esc_html__( 'Coupon Content', 'plumbio-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'Coupons & special offers cannot be combined with other offers. Valid toward standard pricing only.', 'plumbio-core' ),
			)
		);

		$repeater->add_control(
			'item_coupon_date',
			array(
				'label'   => esc_html__( 'Coupon Date', 'plumbio-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( '* Expires: 12/31/2021', 'plumbio-core' ),
			)
		);

		$repeater->add_control(
			'item_print_btn_text',
			array(
				'label'   => esc_html__( 'Print Button Text', 'plumbio-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'Print coupon', 'plumbio-core' ),
			)
		);
		$repeater->add_control(
			'item_url',
			array(
				'label'         => esc_html__( 'URL', 'plumbio-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => esc_html__( 'https://your-link.com', 'plumbio-core' ),
				'show_external' => true,
				'default'       => array(
					'url'         => '',
					'is_external' => false,
					'nofollow'    => false,
				),

			)
		);
		$this->add_control(
			'items',
			array(
				'label'   => esc_html__( 'Repeater List', 'plumbio-core' ),
				'type'    => Controls_Manager::REPEATER,
				'fields'  => $repeater->get_controls(),
				'default' => array(
					array(
						'list_title'   => esc_html__( 'Title #1', 'plumbio-core' ),
						'list_content' => esc_html__( 'Item content. Click the edit button to change this text.', 'plumbio-core' ),
					),

				),
			)
		);
		$this->end_controls_section();
	}
	protected function render() {

		global $plumbio_options;
		$redix_opt_prefix = 'plumbio_';

		if ( ( isset( $plumbio_options[ $redix_opt_prefix . 'primary_color' ] ) ) && ( ! empty( $plumbio_options[ $redix_opt_prefix . 'primary_color' ] ) ) ) {
			$plumbio_main_color = $plumbio_options[ $redix_opt_prefix . 'primary_color' ];
		}else{
			$plumbio_main_color = "#0c4c93";
		}
		if ( ( isset( $plumbio_options[ $redix_opt_prefix . 'third_color' ] ) ) && ( ! empty( $plumbio_options[ $redix_opt_prefix . 'third_color' ] ) ) ) {
			$plumbio_third_color = $plumbio_options[ $redix_opt_prefix . 'third_color' ];
	  	}else{
			$plumbio_third_color = "#ff4917";
		}
		$settings    = $this->get_settings_for_display();
		$block_title = $settings['block_title'];
		$tag_line    = $settings['tag_line'];
		$heading     = $settings['heading'];
		$description = $settings['description'];
		?> 
		<div class="section-indent">
			<div class="container container__fluid-xl">
				<div class="blocktitle text-center blocktitle__min-width03">
					<div class="blocktitle__under"><?php echo $block_title; ?></div>
					<div class="blocktitle__subtitle"><?php echo $tag_line; ?></div>
					<div class="blocktitle__title"><?php echo $heading; ?></div>
					<div class="blocktitle__text"><?php echo $description; ?> </div>
				</div>
				<!-- carusel -->
				<div class="swiper-container imgbox-inner__wrapper swiper__grid js-align-layout two-items-slider" data-carousel="swiper" data-space-between="30" data-slides-sm="1" data-slides-md="1" data-slides-lg="2" data-slides-xl="2" data-slides-xxl="2" data-autoplay-Delay="5000">
					<div class="swiper-wrapper">
						<?php
						$i = 1;
						foreach ( $settings['items'] as $item ) {
							$item_coupon_price      = $item['item_coupon_price'];
							$item_coupon_price_text = $item['item_coupon_price_text'];
							$item_coupon_subtitle   = $item['item_coupon_subtitle'];
							$item_coupon_title      = $item['item_coupon_title'];
							$item_coupon_content    = $item['item_coupon_content'];
							$item_coupon_date       = $item['item_coupon_date'];
							$item_print_btn_text    = $item['item_print_btn_text'];
							$item_url           = $item['item_url']['url'];
							$item_url_external  = $item['item_url']['is_external'] ? 'target="_blank"' : '';
							$item_url_nofollow  = $item['item_url']['nofollow'] ? 'rel="nofollow"' : '';
							?>
							<div class="swiper-slide">
								<div class="tt-coupon-bg lazyload" id="printThis<?php echo $i; ?>" data-bg="<?php echo PLUMBIO_CORE_ASSETS; ?>/images/coupon-bg.png">
								<div class="tt-coupon js-align-layout__item">
									<div class="tt-coupon__label">
										<div class="tt-text01"><?php echo $item_coupon_price; ?></div>
										<div class="tt-text02"><?php echo $item_coupon_price_text; ?></div>
									</div>
									<div class="tt-coupon__subtitle">
										<?php echo $item_coupon_subtitle; ?>
									</div>
									<div class="tt-coupon__title">
										<?php echo $item_coupon_title; ?>
									</div>
									<div class="tt-coupon__content">
										<?php echo $item_coupon_content; ?>
									</div>
									<div class="tt-coupon__row">
										<div class="tt-coupon__col">
											<div class="tt-coupon__notes">
												<?php echo $item_coupon_date; ?>
											</div>
										</div>
										<div class="tt-coupon__col">
											<a href="javascript:void(0)" class="tt-coupon__print" id="btn_save_and_close_for_ele<?php echo $i; ?>" ><?php echo $item_print_btn_text; ?></a>
										</div>
									</div>
								</div>
								</div>
							</div> 
								
							<?php
							$i++;
							$j = $i;
						} ?>
							<script>
								<?php for($i = 1; $i <= $j; $i++){ ?>
								const printButton<?php echo $i; ?> = document.getElementById("btn_save_and_close_for_ele<?php echo $i; ?>");
						        // Get the corresponding div element
						        const printThisDiv<?php echo $i; ?> = document.getElementById("printThis<?php echo $i; ?>");

						        // Add a click event listener to the button
						        printButton<?php echo $i; ?>.addEventListener('click', function () {

						            printDiv(printThisDiv<?php echo $i; ?>);
						        });
					    		<?php } ?>
						        function printDiv(div) {
        							var printWindow = window.open('', '', 'width=400,height=560');
									printWindow.document.write('<html><head><style type="text/css">');
									printWindow.document.write('.tt-coupon__subtitle{text-align:right}.tt-coupon__label,.tt-coupon__print,.tt-coupon__subtitle,.tt-coupon__title{font-family:Mulish,sans-serif;font-weight:800}.tt-coupon,.tt-coupon-bg{background-repeat:no-repeat;background-position:0 0}.tt-coupon{display:flex;flex-direction:column;flex-wrap:nowrap;justify-content:flex-start;position:relative;border:11px solid #f8f8fa;border-left-color:#fff;background-color:#fff;padding:21px 27px 21px 20px;}.tt-coupon__label,.tt-coupon__label:before{background-color:<?php echo $plumbio_third_color; ?>;position:absolute}.tt-coupon__label{display:flex!important;flex-direction:column;flex-wrap:wrap;justify-content:center;align-content:center;align-items:center;width:117px;height:76px;color:#fff;text-align:center;top:-11px;left:-11px;line-height:26px;padding-left:7px}.tt-coupon__label>*{position:relative;z-index:1}.tt-coupon__label .tt-text01{font-size:36px;line-height:1}.tt-coupon__label .tt-text02{font-size:16px;line-height:1;letter-spacing:.1em;margin-top:1px}.tt-coupon__label:before{content:"";display:block;top:0;right:-18px;width:50px;height:100%;z-index:0;-webkit-transform:skew(-26deg);transform:skew(-26deg)}.tt-coupon__subtitle{color:<?php echo $plumbio_third_color; ?>;font-size:16px;letter-spacing:.11em}.tt-coupon__title{color:<?php echo $plumbio_main_color; ?>;font-size:42px;line-height:1.2;margin-top:3px;padding-left:70px;text-align:right}.tt-coupon__content{max-width:396px;margin-left:auto;text-align:right;margin-top:12px}.tt-coupon__row{width:100%;display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:space-between;align-content:stretch;align-items:flex-start;margin-top:17px}.tt-coupon__notes{font-size:13px}.tt-coupon__print{color:<?php echo $plumbio_main_color; ?>;display:inline-block;position:relative}.tt-coupon__print:before{content:"";display:block;position:absolute;bottom:3px;width:0%;height:2px;margin:auto;left:0;background-color:currentColor;transition:width .2s linear}.tt-coupon__print:hover{color:<?php echo $plumbio_main_color; ?>}.tt-coupon__print:hover:before{width:100%}.tt-coupon-bg{background-color:#fff}.tt-coupon-bg .tt-coupon{background-color:transparent}@media (max-width:1229.98px){.tt-coupon__label .tt-text01{font-size:30px}.tt-coupon__label{width:100px}.tt-coupon__title{font-size:32px}}@media (max-width:1024.98px){.tt-coupon__label .tt-text01{font-size:25px}.tt-coupon__label{width:80px}.tt-coupon__subtitle{letter-spacing:.06em}.tt-coupon__title{font-size:24px}}@media (max-width:767.98px){.tt-coupon{padding:21px 27px 21px 0}}@media (max-width:575.98px){.tt-coupon{padding:21px 20px 21px 0}.tt-coupon__label .tt-text01,.tt-coupon__title{font-size:20px}.tt-coupon__label{width:65px;height:62px}.tt-coupon__subtitle{font-size:14px}}.tt-coupon{background-image:url("<?php echo PLUMBIO_CORE_ASSETS; ?>/images/coupon-bg.png");display:flex;flex-direction:column;flex-wrap:nowrap;justify-content:flex-start;align-content:stretch;align-items:flex-end;position:relative;border:11px solid #f8f8fa;border-left-color:#fff;background-color:#fff;background-repeat:no-repeat;background-position:0 0;padding:21px 27px 21px 20px;height:auto}');
							        printWindow.document.write('</style></head><body>');
        							printWindow.document.write(div.innerHTML);
							        printWindow.document.write('</body></html>');
									printWindow.document.close();
									printWindow.focus();
							        printWindow.print();
								}
						    </script>
					</div>
					<div class="swiper-pagination swiper-pagination__center"></div>
				</div>
				<!-- /carusel -->

			</div>
		</div> 

		<?php
	}

	protected function content_template() {    }
}
